@@ -14,7 +14,7 @@ def get_mmr_details_by_puuid_v1(
 
 def get_mmr_details_by_puuid_v2(
     region: str, puuid: str, filter: Optional[str] = None, **kwargs
-) -> Union[MMRDetailsV2, ErrorResponse]:
+) -> Union[MMRDetailsV2, SeasonDataV2, ErrorResponse]:
     return get_mmr_details_by_puuid("v2", region, puuid, filter, **kwargs)
 
 
@@ -26,7 +26,7 @@ def get_mmr_details_by_name_v1(
 
 def get_mmr_details_by_name_v2(
     region: str, name: str, tag: str, filter: Optional[str] = None, **kwargs
-) -> Union[MMRDetailsV2, ErrorResponse]:
+) -> Union[MMRDetailsV2, SeasonDataV2, ErrorResponse]:
     return get_mmr_details_by_name("v2", region, name, tag, filter, **kwargs)
 
 
@@ -40,11 +40,11 @@ def get_mmr_details_by_name(
 ) -> Union[MMRDetailsV1, MMRDetailsV2, SeasonDataV2, ErrorResponse]:
     response = fetch_endpoint(
         EndpointsConfig.MMR_DETAILS_BY_NAME,
-        {"filter": str(filter).lower()} if filter is not None else {},
         region=region,
         name=name,
         tag=tag,
         version=version,
+        query_args={"filter": str(filter).lower()} if filter is not None else None,
         **kwargs,
     )
     response_data = response.json()
@@ -74,10 +74,10 @@ def get_mmr_details_by_puuid(
 ) -> Union[MMRDetailsV1, MMRDetailsV2, SeasonDataV2, ErrorResponse]:
     response = fetch_endpoint(
         EndpointsConfig.MMR_DETAILS_BY_PUUID,
-        {"filter": str(filter).lower()} if filter is not None else {},
         region=region,
         puuid=puuid,
         version=version,
+        query_args={"filter": str(filter).lower()} if filter is not None else None,
         **kwargs,
     )
     response_data = response.json()
